@@ -97,7 +97,7 @@
 '''
 
 
-__all__ = 'access', 'public', 'fail'
+__all__ = 'access', 'public', 'fail', 'MethodAccessibility', 'MethodAuthorization'
 
 
 class MethodAccessibility:
@@ -125,8 +125,8 @@ class MethodAuthorization:
 
 
   @classmethod
-  def _getCheckers(cls, method):
-    '''Get access checker function of the passed method'''
+  def getCheckers(cls, method):
+    '''Get access checker list of the passed method'''
     
     return getattr(method, cls.CheckerAttributeName, cls.default)
 
@@ -143,7 +143,7 @@ class MethodAuthorization:
   def authorize(cls, method, request):
     '''Check if access is allowed'''
     
-    return all(ac(method, request) for ac in cls._getCheckers(method))
+    return all(ac(method, request) for ac in cls.getCheckers(method))
 
 
 def access(accessChecker):
