@@ -311,9 +311,9 @@ class Service(object):
   def onException(self, exception):
     pass
 
-  def preDispatch(self, request):
+  def preDispatch(self, request, method):
     pass
 
-  def postDispatch(self, request):
+  def postDispatch(self, request, method):
     pass
 
