@@ -118,11 +118,11 @@ class Service(rpc.Service):
   def onException(self, exception):
     self.state.append(('onException', exception))
 
-  def preDispatch(self, request):
-    self.state.append(('preDispatch', request))
+  def preDispatch(self, request, method):
+    self.state.append(('preDispatch', request, method))
 
-  def postDispatch(self, request):
-    self.state.append(('postDispatch', request))
+  def postDispatch(self, request, method):
+    self.state.append(('postDispatch', request, method))
 
   @rpc.public
   def error(self, type):
