@@ -248,6 +248,11 @@ class TestGeneral(test.TestCase):
     item = test.Service.state.pop(0)
     self.assertEqual('preDispatch', item[0])
     self.assertIsInstance(item[1], rpc.Request)
+    try:
+      self.assertIs(item[2].__func__, test.Service.add.__func__)  # @UndefinedVariable
+    except AttributeError:
+      # Python 3 compatibility, unbound methods have gone
+      self.assertIs(item[2].__func__, test.Service.add)  # @UndefinedVariable
     
     item = test.Service.state.pop(0)
     self.assertEqual('add', item[0])
@@ -256,6 +261,11 @@ class TestGeneral(test.TestCase):
     item = test.Service.state.pop(0)
     self.assertEqual('postDispatch', item[0])
     self.assertIsInstance(item[1], rpc.Request)
+    try:
+      self.assertIs(item[2].__func__, test.Service.add.__func__)  # @UndefinedVariable
+    except AttributeError:
+      # Python 3 compatibility, unbound methods have gone
+      self.assertIs(item[2].__func__, test.Service.add)  # @UndefinedVariable
     
   def testSystemError(self):
     self._post('error', 'sys')
